import PropTypes from 'prop-types';
import { useMemo } from 'react';
import classes from './styles.module.scss';

const ArcArrow = function ArcArrow(props) {
  const { start, length, reversed } = props;
  const w = 100;
  const r = w / 2;
  const arrow = 16;

  const arrowProps = useMemo(() => {
    const startRadians = start * (Math.PI / 180);
    const endRadians = (start + length) * (Math.PI / 180);

    const flag = length > 180 ? '0 1 1' : '0 0 1';

    const startX = r + r * Math.cos(startRadians);
    const startY = r + r * Math.sin(startRadians);

    const endX = r + r * Math.cos(endRadians);
    const endY = r + r * Math.sin(endRadians);

    const arrowPos = reversed
      ? { x: startX, y: startY }
      : { x: endX, y: endY };

    const arrowDeg = reversed
      ? start + 180
      : start + length;

    return {
      startX, startY, endX, endY, arrowPos, arrowDeg, flag,
    };
  }, [start, length, reversed]);

  const {
    startX, startY, endX, endY, arrowPos, arrowDeg, flag,
  } = arrowProps;

  return (
    <svg
      viewBox={`0 0 ${w} ${w}`}
      className={classes['arc-arrow']}
    >
      <path
        className={classes.tail}
        d={`M${startX} ${startY} A50 50 ${flag} ${endX} ${endY}`}
      />
      <path
        className={classes.arrow}
        d={`M${-arrow / 2} ${-arrow * 0.7} L${arrow / 2} ${-arrow * 0.7} L${0} ${arrow / 2} Z`}
        transform={`translate(${arrowPos.x}, ${arrowPos.y}) rotate(${arrowDeg})`}
      />
    </svg>
  );
};

ArcArrow.defaultProps = {
  start: 0,
  length: 0,
  reversed: false,
};

ArcArrow.propTypes = {
  /**
   * What degree does the number start at
   */
  start: PropTypes.number,
  /**
   * How many degrees does the arc spawn
   */
  length: PropTypes.number,
  /**
   * True means the arrow is placed at the start of the arc
   * False means the arrow is placed at the end of the arc
   */
  reversed: PropTypes.bool,
};

export default ArcArrow;
