import PropTypes from 'prop-types';
import classnames from 'classnames';
import classes from './styles.module.scss';

const Button = function Button(props) {
  const { size, children, href } = props;

  return (
    <div className={
      classnames(
        classes.button,
        classes[size],
      )
}
    >
      <a href={href} target="_blank" rel="noreferrer">
        {children}
      </a>
    </div>
  );
};

Button.defaultProps = {
  size: 'lg',
  children: '',
  href: null,
};

Button.propTypes = {
  /**
   * The size variant to use
   */
  size: PropTypes.oneOf(['sm', 'lg']),
  /**
   * The contents of the button
   */
  children: PropTypes.string,
  /**
   * An external link
   */
  href: PropTypes.string,
};

export default Button;
