import classnames from 'classnames';
import PropTypes from 'prop-types';

import classes from './styles.module.scss';

const defaultThemes = {
  magazine: 'dark',
  default: 'light',
};

const Navigation = (props) => {
  const {
    classes: additionalClasses,
    site: siteFromProps,
    theme: themeFromProps,
  } = props;
  const site = siteFromProps.toLowerCase();
  const theme = themeFromProps || defaultThemes[site] || defaultThemes.default;

  const {
    container: containerClass,
    header: headerClass,
    branding: brandingClass,
    home: homeClass,
    links: linksClass,
  } = additionalClasses;

  return (
    <nav
      title="navigation"
      className={classnames(
        classes.navigation,
        'global',
        containerClass,
      )}
    >
      <div
        className={classnames(
          classes.header,
          headerClass,
          {
            [classes.magazine]: site === 'magazine',
            [classes.dark]: theme === 'dark',
            [classes.light]: theme === 'light',
          },
        )}
      >
        <div className={classes['header-content']}>
          <div
            className={classnames(
              classes.branding,
              brandingClass,
            )}
          >
            {site === 'magazine' && (
              <a
                className={classnames(classes.link, 'navbar-brand')}
                href="https://www.politico.com/magazine/"
                title="POLITICO"
                target="_top"
              >
                <span className={classnames(
                  'bt-icon',
                  'bt-icon--politico',
                  classes['bt-icon--politico'],
                )}
                />
                <span className={classnames(
                  'bt-icon',
                  'bt-icon--magazine',
                  classes['bt-icon--magazine'],
                )}
                />
              </a>
            )}
            {site !== 'magazine' && (
              <a
                className={classnames(classes.link, 'navbar-brand')}
                href="https://www.politico.com/"
                title="POLITICO"
                target="_top"
              >
                <span
                  className={classnames(
                    'bt-icon',
                    'bt-icon--politico',
                    classes['bt-icon--politico'],
                  )}
                />
              </a>
            )}
          </div>

          <nav className={classes['header-wrapper']}>
            <div
              className={classnames(
                classes['header-content'],
                homeClass,
              )}
            >
              <div className="header-left">
                <a
                  className={classnames(classes.link)}
                  href="https://www.politico.com"
                >
                  <svg
                    xmlns="http://www.w3.org/2000/svg"
                    height="20px"
                    version="1.1"
                    x="0px"
                    y="0px"
                    viewBox="0 0 100 100"
                    enableBackground="new 0 0 100 100"
                    xmlSpace="preserve"
                  >
                    <path
                      d={
                        'M79.5,81.458h-57V41.27L51,16.729L79.5,41.27V81.458z '
                        + 'M25.5,78.458h51V42.646L51,20.688L25.5,'
                        + '42.646V78.458z'
                      }
                    />
                  </svg>
                </a>
              </div>

              <div
                className={classnames(
                  classes['header-right'],
                  linksClass,
                )}
              >
                <ul className={classes['micro-list']}>
                  {site !== 'magazine' && (
                    <li>
                      <a
                        className={classnames(
                          classes.link,
                          classes['header-link'],
                          {
                            [classes.dark]: theme === 'dark',
                            [classes.light]: theme === 'light',
                          },
                        )}
                        href="https://www.politico.com/magazine/"
                        target="_top"
                      >
                        Magazine
                      </a>
                    </li>
                  )}
                  <li className="subnav">
                    <a
                      className={classnames(
                        classes['header-link'],
                        {
                          [classes.dark]: theme === 'dark',
                          [classes.light]: theme === 'light',
                        },
                      )}
                      href="https://www.politicopro.com"
                      target="_top"
                    >
                      PRO
                    </a>
                  </li>
                  <li className="subnav">
                    <a
                      className={classnames(
                        classes['header-link'],
                        {
                          [classes.dark]: theme === 'dark',
                          [classes.light]: theme === 'light',
                        },
                      )}
                      href="https://www.eenews.net/"
                      target="_top"
                    >
                      E&E News
                    </a>
                  </li>
                </ul>
              </div>
            </div>
          </nav>
        </div>
      </div>
    </nav>
  );
};

Navigation.defaultProps = {
  site: '',
  classes: {},
  theme: undefined,
};

Navigation.propTypes = {
  /**
   * Which subsite header to use
   */
  site: PropTypes.oneOf(['', 'magazine']),
  /**
    * Which theme to use
    */
  theme: PropTypes.oneOf(['dark', 'light']),
  /**
   * Additional style classes
   */
  classes: PropTypes.shape({
    container: PropTypes.string,
    header: PropTypes.string,
    branding: PropTypes.string,
    home: PropTypes.string,
    links: PropTypes.string,
  }),
};

export default Navigation;
