// TODO: Try to fix this lint error without the disable
/* eslint-disable react/no-array-index-key */
import React, { Fragment } from 'react';
import classnames from 'classnames';
import renderLeaf from './renderLeaf';

import Tweet from '../nodes/Tweet';
import CodeNode from '../nodes/Code';
import IframeNode from '../nodes/Iframe';

function renderNode(data, props) {
  const { type, leaves, data: nodeData } = data;
  const { active, classes } = props;

  if (leaves) {
    return leaves.map((d, idx) => (
      <span key={idx} className={classes.leaf}>
        {renderLeaf(d, props)}
      </span>
    ));
  }

  if (type) {
    const children = (
      <>
        {data.nodes.map((d, idx) => (
          <span
            key={idx}
            className={classnames(
              classes.node,
              classes['inner-node'],
            )}
          >
            {renderNode(d, props)}
          </span>
        ))}
      </>
    );

    switch (type) {
      case 'blockquote':
        return (
          <blockquote className={classnames(classes.blockquote)}>
            {children}
          </blockquote>
        );
      case 'bulleted-list':
        return (
          <ul className={classnames(classes.list, classes.bullets)}>
            {children}
          </ul>
        );
      case 'list-item':
        return (
          <li className={classnames(classes.text, classes.item)}>
            {children}
          </li>
        );
      case 'numbered-list':
        return (
          <ol className={classnames(classes.list, classes.numbered)}>
            {children}
          </ol>
        );
      case 'paragraph':
        return (
          <p className={classnames(classes.text, classes.paragraph)}>
            {children}
          </p>
        );
      case 'link':
        return (
          <a
            className={classes.link}
            href={nodeData.href}
          >
            {children}
          </a>
        );
      case 'image':
        return (
          <figure className={classes['image-container']}>
            <img
              className={classes.image}
              src={nodeData.canonical}
              alt="Custom – missing alt text"
            />
          </figure>
        );
      case 'tweet':
        return (
          <Tweet
            className={classes['tweet-container']}
            tweet={nodeData.url}
          />
        );
      case 'youtube':
        return (
          <div className={classes['youtube-container']}>
            <CodeNode
              active={active}
              code={nodeData.html}
            />
          </div>
        );
      case 'code':
        return (
          <CodeNode
            className={classes['code-container']}
            active={active}
            code={nodeData.code}
          />
        );
      case 'iframe':
        return (
          <IframeNode
            className={classes.iframe}
            active={active}
            code={nodeData.code}
          />
        );
      default:
        return () => null;
    }
  }

  return null;
}

export default renderNode;
