import classnames from 'classnames';
import PropTypes from 'prop-types';

import baseClasses from './styles.module.scss';

const SkipNav = (props) => {
  const { classes } = props;
  const {
    root: rootClass,
    action: actionClass,
  } = classes;

  return (
    <div className={classnames(
      baseClasses['skip-nav'],
      rootClass,
    )}
    >
      <ul className={baseClasses['skip-nav__list']}>
        <li
          className={classnames(
            baseClasses['skip-nav__action'],
            actionClass,
          )}
        >
          <button
            type="button"
            className={baseClasses['skip-nav__link']}
            onClick={() => {
              window.document.querySelector('#maincontent').focus();
            }}
          >
            Skip to main content
          </button>
        </li>
        <li
          className={classnames(
            baseClasses['skip-nav__action'],
            actionClass,
          )}
        >
          <button
            type="button"
            className={baseClasses['skip-nav__link']}
            onClick={() => {
              window.document.querySelector('#sitemap').focus();
            }}
          >
            Skip to footer site map
          </button>
        </li>
      </ul>
    </div>
  );
};

export default SkipNav;

SkipNav.defaultProps = {
  classes: {},
};

SkipNav.propTypes = {
  /**
   * Additional style classes
   */
  classes: PropTypes.shape({
    root: PropTypes.string,
    action: PropTypes.string,
  }),
};

export const SkipToMainContent = () => (
  <div id="maincontent" tabIndex="-1" />
);

export const SkipToSitemap = () => (
  <div id="sitemap" tabIndex="-1" />
);
